@@ -7,6 +7,7 @@ import typing
 from lime_uow import resources, exceptions
 
 __all__ = (
+    "PlaceholderUnitOfWork",
     "SharedResources",
     "UnitOfWork",
 )
@@ -115,6 +116,21 @@ class UnitOfWork(abc.ABC):
             raise
 
 
+class PlaceholderUnitOfWork(UnitOfWork):
+    def __init__(self):
+        super().__init__()
+
+    def create_resources(
+        self, shared_resources: SharedResources
+    ) -> typing.List[resources.Resource[typing.Any]]:
+        return []
+
+    def create_shared_resources(
+        self,
+    ) -> typing.Iterable[resources.SharedResource[typing.Any]]:
+        return []
+
+
 class SharedResources:
     def __init__(self, /, *shared_resource: resources.SharedResource[typing.Any]):
         _check_for_duplicate_resource_names(shared_resource)
